package cn.teammodel.dao;

import cn.teammodel.model.entity.appraise.AppraiseRecord;
import cn.teammodel.model.vo.appraise.AppraiseRecordVo;
import com.azure.spring.data.cosmos.repository.CosmosRepository;
import com.azure.spring.data.cosmos.repository.Query;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * @author winter
 * @create 2023-11-20 14:39 <br/>
 * Page<User> findByLastname(String lastname, Pageable pageable); <br/>
 * Slice<User> findByLastname(String lastname, Pageable pageable);<br/>
 * Window<User> findTop10ByLastname(String lastname, ScrollPosition position, Sort sort);<br/>
 * List<User> findByLastname(String lastname, Sort sort);<br/>
 * List<User> findByLastname(String lastname, Sort sort, Limit limit);<br/>
 * List<User> findByLastname(String lastname, Pageable pageable);<br/>
 */
@Repository
public interface AppraiseRecordRepository extends CosmosRepository<AppraiseRecord, String> {

    /**
    * 查询评价记录
    */
    AppraiseRecord findAppraiseRecordByTargetIdAndClassIdAndAcademicYearIdAndCode(String targetId, String classId, String academicYearId, String code);
    @Query("select c.id, c.praiseCount, c.score from Student as c where c.targetId = @targetId and c.academicYearId = @academicYearId and c.code = @code")
    List<AppraiseRecord> findScoreAndPraise(String targetId,String academicYearId,String code);

    /**
    * 条件查询
    */
    @Query("select c.id as recordId, c.name, c.avatar, c.targetId, c.targetType, n as info from Student as c join n in c.nodes where " +
            "(IS_NULL(@targetId) or c.targetId = @targetId) and " +
            "(IS_NULL(@targetType) or c.targetType = @targetType) and " +
            "(IS_NULL(@classId) or c.classId = @classId) and " +
            "(IS_NULL(@creatorId) or n.creatorId = @creatorId) and " +
            "(IS_NULL(@academicYearId) or c.academicYearId = @academicYearId) and " +
            "c.code = @code")
    List<AppraiseRecordVo> searchNodesByCondition(String targetId, String targetType, String classId, String creatorId, String academicYearId, String code);


}
